ActPackageDefinition

Struct ActPackageDefinition 

pub struct ActPackageDefinition {
    pub id: &'static str,
    pub name: &'static str,
    pub desc: &'static str,
    pub icon: &'static str,
    pub doc: &'static str,
    pub version: &'static str,
    pub schema: Value,
    pub options: Option<Value>,
    pub run_as: ActRunAs,
    pub resources: Vec<ActResource>,
    pub catalog: ActPackageCatalog,
}

Fields

id: &'static str

package id, used to identify the package

name: &'static str

package simple name

desc: &'static str

package description

icon: &'static str

icon name to display in the editor ui

doc: &'static str

releated doc url to show the help

version: &'static str

package version

schema: Value

json schema for package params

options: Option<Value>

extra options

run_as: ActRunAs

package run as Irq, Msg or Func Func is only used internally

resources: Vec<ActResource>

package resources to the orgnize multiple resources it is used for the editor ui to search and select the resources each resource value can fill the special value into the UI

catalog: ActPackageCatalog

package catalog

Implementations