pub struct ActPackageDefinition {
pub id: &'static str,
pub name: &'static str,
pub desc: &'static str,
pub icon: &'static str,
pub doc: &'static str,
pub version: &'static str,
pub schema: Value,
pub options: Option<Value>,
pub run_as: ActRunAs,
pub resources: Vec<ActResource>,
pub catalog: ActPackageCatalog,
}Fields
id: &'static strpackage id, used to identify the package
name: &'static strpackage simple name
desc: &'static strpackage description
icon: &'static stricon name to display in the editor ui
doc: &'static strreleated doc url to show the help
version: &'static strpackage version
schema: Valuejson schema for package params
options: Option<Value>extra options
run_as: ActRunAspackage run as Irq, Msg or Func Func is only used internally
resources: Vec<ActResource>package resources to the orgnize multiple resources it is used for the editor ui to search and select the resources each resource value can fill the special value into the UI
catalog: ActPackageCatalogpackage catalog
Implementations